# RecordV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**orcid_identifier** | [**OrcidIdentifierV20**](OrcidIdentifierV20.md) |  | [optional] 
**preferences** | [**PreferencesV20**](PreferencesV20.md) |  | [optional] 
**history** | [**HistoryV20**](HistoryV20.md) |  | [optional] 
**person** | [**PersonV20**](PersonV20.md) |  | [optional] 
**activities_summary** | [**ActivitiesSummaryV20**](ActivitiesSummaryV20.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

